/* Program: ffmpegPickup
 * Author: Alex Sneeringer
 * Last Modification Date: 10:13PM 6/9/2004
 * Last Modified By: Alex Sneeringer
 * 
 * Description: This program is designed to pick up files from a location and parse through
 * them for a particular data.  This data is then used in part with the data from the properties
 * file from the program to convert/compress the files.
 * 
 * The input file, referred to as the pickup file has a particular xml format that the data is pulled
 * from. A sample is given below, all the data for the conversion can be gathered from the xml input file.
 * However, the user has the ability to override these settings with the property file that is also xml and 
 * has a particular format.  A sample properties file is also given. 
 */



/*	/////////////////////////
	   SAMPLE PICKUP FILE
	/////////////////////////
	
	<?xml version="1.0" encoding="ISO-8859-1" ?> 
	<Airing>
	<Title>Stephen King's Kingdom Hospital</Title> 
	<Episode>Seizure Day</Episode> 
	<Description>After having seizures, two patients begin to have visions of the living dead haunting the hospital.</Description> 
	<ActualStartTime>1088730000000</ActualStartTime> 
	<StartDate>Jul 1, 2004</StartDate> 
	<StartTime>9:00:00 PM</StartTime> 
	<EndTime>10:01:00 PM</EndTime> 
	<File>W:\SageTV\StephenKingsKingdomHospitalSeizureDay-2037013-0.mpg</File> 
	<TargetRoot>m:\Compressed</TargetRoot> 
	<VideoBitrate>1800</VideoBitrate> 
	<AudioBitrate>192</AudioBitrate>
	<DeleteWhenComplete>true</DeleteWHenComplete>
	<FirstRun>true</FirstRun> 
	<Favorite>true</Favorite> 
	<Manual>false</Manual> 
	<Watched>false</Watched> 
	</Airing>

	/////////////////////////////
	   SAMPLE PROPERTIES FILE
	/////////////////////////////
	
	<?xml version = "1.0" ?>
	<properties>
		<!-- Use . to specify the application path -->
		<Pickup_Location>.\\pickup</Pickup_Location>
		<Pickup_File_Extension>.xml</Pickup_File_Extension>
		<Create_MY_File>True</Create_MY_File>
		<Exe_Command>
			<Value>ffmpeg -i @INPUT -deinterlace -y -f @OUTPUT_FORMAT -vcodec @VCODEC -b @VIDEO_RATE -g 300 -bf 2 -acodec @ACODEC -ab @AUDIO_RATE @OUTPUT_FORMAT</Value>
			<Enabled>False</Enabled>
		</Exe_Command>
		<Output_Format>
			<Value>avi</Value>
			<Enabled>False</Enabled>
		</Output_Format>
		<VCodec>
			<Value>mpeg4</Value>
			<Enabled>False</Enabled>
		</VCodec>
		<ACodec>
			<Value>mp2</Value>
			<Enabled>False</Enabled>
		</ACodec>
		<Video_Rate>
			<Value>700</Value>
			<Enabled>True</Enabled>
		</Video_Rate>
		<Audio_Rate>
			<Value>128</Value>
			<Enabled>True</Enabled>
		</Audio_Rate>
		<Library_Path>
			<Value>.\\Library</Value>
			<Enabled>True</Enabled>
		</Library_Path>
	</properties>

	////////////////////
	   SAMPLE MY FILE
	////////////////////

	Here is the current .my format:
	title=Stephen Kinds Kingdom Hospital::Seizure Day
	overview=After having seizures, two patients begin to have visions of the living dead haunting the hospital.
	released=Jul 1, 2004 9:00:00 PM
*/

public class ffmpegPickup
{
	public static void main (String [] args)
	{
		String props_filename = "properties.xml";

		//process the arguments of the program
		if (args.length > 1)
		{
			System.out.println ("==========================================================================");
			System.out.println ("Incorrect usage of this program, please use the following syntax:\n");
			System.out.println ("\t%JAVA_LOCATION%\\java ffmpegPickup [filename]\n\n");
			System.out.println ("Note: The filename is optional and the default is properties.xml.");
			System.out.println ("==========================================================================");
			return;
		}
		else if (args.length == 1)
		{
			props_filename = args[0];
		}

		ffmpegProcessor runConv = new ffmpegProcessor(props_filename);

		//verify the props file could be read and understood first
		if (runConv.invalidSetup() == true)
		{
			System.out.println ("[Error running the program]\n" +
								 "There is an error with your properties file, it could not be understood by the program.");
			return;
		}
		else
		{
			runConv.start();
		}
	}	
}